@@ -93,7 +93,7 @@ public class Lexer extends gnu.text.Lexer
     if (c >= 0)
       i--;   // Reset to position before current char c.
     port.pos = i;
-    long ival = Lexer.readDigitsInBuffer(port, radix);
+    long ival = Lexer.readDigitsInBuffer(port, 0, radix);
     boolean digit_seen = port.pos > i;
     if (digit_seen && port.pos < port.limit)
       {
