@@ -1,4 +1,4 @@
-// Copyright (c) 1999, 2000-2005, 2006, 2010 Per M.A. Bothner.
+// Copyright (c) 1999, 2000-2005, 2006, 2010, 2014 Per M.A. Bothner.
 // This is free software;  for terms and warranty disclaimer see ./COPYING.
 
 package gnu.expr;
@@ -10,8 +10,7 @@ import kawa.Shell;
 import java.util.zip.*;
 import java.util.Stack;
 import gnu.kawa.functions.Convert;
-import gnu.kawa.io.OutPort;
-import gnu.kawa.io.Path;
+import gnu.kawa.io.*;
 import gnu.kawa.lispexpr.LangPrimType;
 import gnu.kawa.reflect.LazyType;
 import gnu.lists.Pair;
@@ -128,6 +127,9 @@ public class Compilation implements SourceLocator
   /** If true, print out final expressions after optimizations etc. */
   public static boolean debugPrintFinalExpr;
 
+  public static boolean debugPrintANF = false;
+  public static boolean enableANF = false;
+  
   public static Options options = new Options();
   public static Options.OptionInfo fullTailCallsVariable =
     options.add("full-tailcalls",
@@ -194,7 +196,7 @@ public class Compilation implements SourceLocator
   }
   public boolean warnVoidUsed()
   {
-    return currentOptions.getBoolean(warnVoidUsed);
+    return (!enableANF) && currentOptions.getBoolean(warnVoidUsed);
   }
   public boolean warnAsError ()
   {
@@ -214,6 +216,9 @@ public class Compilation implements SourceLocator
   }
 
   public static int defaultClassFileVersion =
+    /* #ifdef JAVA9 */
+    // ClassType.JAVA_9_VERSION
+    /* #else */
     /* #ifdef JAVA8 */
     // ClassType.JDK_1_8_VERSION
     /* #else */
@@ -231,6 +236,7 @@ public class Compilation implements SourceLocator
     /* #endif */
     /* #endif */
     /* #endif */
+    /* #endif */
     ;
 
   /** The default calling convention.
@@ -266,9 +272,14 @@ public class Compilation implements SourceLocator
   public static final int MODULE_STATIC_DEFAULT = 0;
   public static final int MODULE_STATIC = 1;
   public static final int MODULE_STATIC_RUN = 2;
-  /** If moduleStatic > 0, (module-static #t) is implied by default.
-   * If moduleStatic == 2, <clinit> calls run.
-   * If moduleStatic < 0, (module-static #f) is implied by default. */
+  /** Default for whether a module is static.
+   * If {@code moduleStatic > 0},
+   *   then {@code (module-static #t)} is implied by default.
+   * If {@code moduleStatic == MODULE_STATIC_RUN},
+   *   then {@code <clinit>} calls {@code run}.
+   * If {@code moduleStatic < 0},
+   *   then {@code (module-static #f)} is implied by default.
+   */
   public static int moduleStatic = MODULE_STATIC_DEFAULT;
 
   ClassType[] classes;
@@ -303,13 +314,13 @@ public class Compilation implements SourceLocator
   static public ClassType typeObject = Type.objectType;
   static public ClassType scmBooleanType = ClassType.make("java.lang.Boolean");
   static public ClassType typeString = ClassType.make("java.lang.String");
+  static public ClassType typeCharSequence = ClassType.make("java.lang.CharSequence");
   static public ClassType javaStringType = typeString;
   static public ClassType scmKeywordType = ClassType.make("gnu.expr.Keyword");
   static public ClassType scmSequenceType = ClassType.make("gnu.lists.Sequence");
   public static final ClassType typeList = ClassType.make("java.util.List");
   static public ClassType scmListType = ClassType.make("gnu.lists.LList");
   static public ClassType typePair = ClassType.make("gnu.lists.Pair");
-  public static final ClassType typeConstVector = ClassType.make("gnu.lists.ConstVector");
   public static final ArrayType objArrayType = ArrayType.make(typeObject);
   static public ClassType typeRunnable = ClassType.make("java.lang.Runnable");
   static public ClassType typeRunnableModule = ClassType.make("gnu.expr.RunnableModule");
@@ -326,6 +337,8 @@ public class Compilation implements SourceLocator
     = ClassType.make("gnu.mapping.Environment");
   static public ClassType typeLocation
     = ClassType.make("gnu.mapping.Location");
+  public static final ClassType typeLocationProc
+    = ClassType.make("gnu.mapping.LocationProc");
   static public ClassType typeFieldLocation
     = ClassType.make("gnu.kawa.reflect.FieldLocation");
   static public ClassType typeStaticFieldLocation
@@ -687,26 +700,46 @@ public class Compilation implements SourceLocator
                             : Type.make(value.getClass()));
   }
 
-  public void emitPushBoolean(boolean value)
-  {
-    getCode().emitGetStatic(value ? Compilation.trueConstant
-                            : Compilation.falseConstant);
-  }
+    /** Push language-specific boxed true or false value. */
+    public void emitPushBoolean(boolean value) {
+        CodeAttr code = getCode();
+        Object valObject = language.booleanObject(value);
+        if (valObject == Boolean.TRUE)
+            code.emitGetStatic(Compilation.trueConstant);
+        else if (valObject == Boolean.FALSE)
+            code.emitGetStatic(Compilation.falseConstant);
+        else compileConstant(valObject);
+    }
 
   /** Generate code to test if an object is considered true.
    * Assume the object has been pushed on the JVM stack.
-   * Generate code to push true or false as appropriate. */
+   * Generate code to push (unboxed) true or false as appropriate. */
   public void emitCoerceToBoolean()
   {
     CodeAttr code = getCode();
-    emitPushBoolean(false);
-    code.emitIfNEq();
+    Label trueLabel = new Label(code);
+    Label falseLabel = new Label(code);
+    ConditionalTarget ctarget
+        = new ConditionalTarget(trueLabel, falseLabel, getLanguage());
+    ctarget.compileFromStack(this, Type.objectType);
+    code.emitIfThen();
+    trueLabel.define(code);
     code.emitPushInt(1);
     code.emitElse();
+    falseLabel.define(code);
     code.emitPushInt(0);
     code.emitFi();
   }
 
+    /** Hook for language-specific handling in ConditionalTarget.
+     * @param stackType Value to be treated as boolean, already pushed.
+     * @return null if we've handled the conditional transfer;
+     *    otherwise type value has been converted to (usually booleanType).
+     */
+    public Type asBooleanValue(ConditionalTarget target, Type stackType) {
+        return stackType;
+    }
+
     boolean dumpingInitializers;
 
     private void dumpInitializers(Initializer inits) {
@@ -717,17 +750,38 @@ public class Compilation implements SourceLocator
         dumpingInitializers = false;
     }
 
+    static final Comparator<ClassType> 
+            classTypeComparator = new Comparator<ClassType>() {
+        public int compare(ClassType arg0, ClassType arg1) {
+            return arg0.getName().compareTo(arg1.getName());
+        }
+    };
+
+    boolean classesArrayIsSorted;
+
   /** Search this Compilation for a ClassType with a given name.
    * @param name the name of the class desired
    * @return the matching ClassType, or null if none is found */
-  public ClassType findNamedClass (String name)
-  {
-    for (int i = 0;  i < numClasses; i++)
-      {
-	if (name.equals (classes[i].getName ()))
-	  return classes[i];
-      }
-    return null;
+    public ClassType findNamedClass(String name) {
+
+        if (classes == null || numClasses == 0)
+            return null;
+
+        if (name.equals(classes[0].getName()))
+                return classes[0];
+
+        if (numClasses == 1)
+            return null;
+
+        if (! classesArrayIsSorted) {
+            Arrays.sort(classes, 1, numClasses, classTypeComparator);
+            classesArrayIsSorted = true;
+        }
+
+        ClassType nameType = new ClassType(name); // wrapper for key
+        int index = Arrays.binarySearch
+                      (classes, 1, numClasses, nameType, classTypeComparator);
+        return (index > -1) ? classes[index] : null;
   }
 
   public static String classPrefixDefault = "";
@@ -815,151 +869,13 @@ public class Compilation implements SourceLocator
     return sbuf.toString();
   }
 
-  public static String mangleName (String name)
-  {
-    return Language.mangleName(name, -1);
-  }
-
-  /** Convert a string to a safe Java identifier.
-   * @param reversible if we should use an invertible mapping.
-   */
-  public static String mangleName (String name, boolean reversible)
-  {
-    return Language.mangleName(name, reversible ? 1 : -1);
-  }
-
-  public static String mangleNameIfNeeded (String name)
-  {
-    return Language.mangleNameIfNeeded(name);
-  }
-
-  /** Demangle a three-character mangling starting with '$'.
-   * UNFINISHED!
-   */
-  public static char demangle2(char char1, char char2)
-  {
-    switch (char1 << 16 | char2)
-      {
-      case 'A' << 16 | 'm':  return '&';
-      case 'A' << 16 | 't':  return '@';
-      case 'C' << 16 | 'l':  return ':';
-      case 'C' << 16 | 'm':  return ',';
-      case 'D' << 16 | 'q':  return '\"';
-      case 'D' << 16 | 't':  return '.';
-      case 'E' << 16 | 'q':  return '=';
-      case 'E' << 16 | 'x':  return '!';
-      case 'G' << 16 | 'r':  return '>';
-      case 'L' << 16 | 'B':  return '[';
-      case 'L' << 16 | 'C':  return '{';
-      case 'L' << 16 | 'P':  return '(';
-      case 'L' << 16 | 's':  return '<';
-      case 'M' << 16 | 'c':  return '%';
-      case 'M' << 16 | 'n':  return '-';
-      case 'N' << 16 | 'm':  return '#';
-      case 'P' << 16 | 'c':  return '%';
-      case 'P' << 16 | 'l':  return '+';
-      case 'Q' << 16 | 'u':  return '?';
-      case 'R' << 16 | 'B':  return ']';
-      case 'R' << 16 | 'C':  return '}';
-      case 'R' << 16 | 'P':  return ')';
-      case 'S' << 16 | 'C':  return ';';
-      case 'S' << 16 | 'l':  return '/';
-      case 'S' << 16 | 'q':  return '\\';
-      case 'S' << 16 | 't':  return '*';
-      case 'T' << 16 | 'l':  return '~';
-      case 'U' << 16 | 'p':  return '^';
-      case 'V' << 16 | 'B':  return '|';
-      }
-    return (char) (-1);
-  }
-
-  public static String demangleName(String name)
-  {
-    return demangleName(name, false);
-  }
-
-  public static String demangleName(String name, boolean reversible)
-  {
-    StringBuffer sbuf = new StringBuffer();
-    int len = name.length();
-    boolean mangled = false;
-    boolean predicate = false;
-    boolean downCaseNext = false;
-    for (int i = 0;  i < len;  i++)
-      {
-	char ch = name.charAt(i);
-        if (i == 0 && ch == '$' && len >= 3 && name.charAt(1) == 'N')
-          {
-            i = 1;
-            mangled = true;
-            continue;
-          }
-	if (downCaseNext && ! reversible)
-	  {
-	    ch = Character.toLowerCase(ch);
-	    downCaseNext = false;
-	  }
-	char d;
-	if (!reversible
-	    && ch == 'i' && i == 0 && len > 2 && name.charAt(i+1) == 's'
-	    && ! Character.isLowerCase(d = name.charAt(i+2)))
-	  {
-	    mangled = true;
-	    predicate = true;
-	    i++;
-	    if (Character.isUpperCase(d) || Character.isTitleCase(d))
-	      {
-		sbuf.append(Character.toLowerCase(d));
-		i++;
-		continue;
-	      }
-	    continue;
-	  }
-	else if (ch == '$' && i + 2 < len)
-	  {
-	    char c1 = name.charAt(i+1);
-	    char c2 = name.charAt(i+2);
-	    d = Compilation.demangle2(c1, c2);
-	    if (d != (char)(-1))
-	      {
-		sbuf.append(d);
-		i += 2;
-		mangled = true;
-		downCaseNext = true;
-		continue;
-	      }
-	    else if (c1 == 'T' && c2 == 'o' && i + 3 < len
-		     && name.charAt(i+3) == '$')
-	      {
-		sbuf.append("->");
-		i += 3;
-		mangled = true;
-		downCaseNext = true;
-		continue;
-	      }
-	  }
-	else if (! reversible && i > 1
-		 && (Character.isUpperCase(ch) || Character.isTitleCase(ch))
-		 && (Character.isLowerCase(name.charAt(i-1))))
-	  {
-	    sbuf.append('-');
-	    mangled = true;
-	    ch = Character.toLowerCase(ch);
-	  }
-	sbuf.append(ch);
-      }
-    if (predicate)
-      sbuf.append('?');
-    return mangled ? sbuf.toString() : name;
-  }
-
   /** Generate an unused class name.
    * @param hint the requested name (or prefix)
    * @return a unique class name.
    */
   public String generateClassName (String hint)
   {
-    hint = mangleName(hint, true);
+    hint = Mangling.mangleClassName(hint);
     if (mainClass != null)
       hint = mainClass.getName() + '$' + hint;
     else if (classPrefix != null)
@@ -1085,6 +1001,7 @@ public class Compilation implements SourceLocator
         classes[0] = mainClass;
       }
     classes[numClasses++] = new_class;
+    classesArrayIsSorted = false;
   }
 
   public void addClass (ClassType new_class)
@@ -1128,7 +1045,8 @@ public class Compilation implements SourceLocator
       }
     if (makeRunnable())
       type.addInterface(typeRunnable);
-    type.addInterface(typeRunnableModule);
+    if (! module.staticInitRun())
+        type.addInterface(typeRunnableModule);
     type.setSuper(sup);
 
     module.compiledType = type;
@@ -1937,7 +1855,7 @@ public class Compilation implements SourceLocator
             if (lexer != null)
                 lexer.close();
             lexer = null;
-            setState(messages.seenErrors() ? ERROR_SEEN : BODY_PARSED);
+            setState(BODY_PARSED);
             if (pendingImports != null)
               return;
           }
@@ -1950,7 +1868,10 @@ public class Compilation implements SourceLocator
             // dealing with eval, mutually recursive modules, etc
             // it doesn't quite work.
             addMainClass(mexp);
-            setState(messages.seenErrors() ? ERROR_SEEN : RESOLVED);
+            if (generateMainMethod() && mexp.staticInitRun()) {
+                error('e', "a static init-run module cannot have a 'main' method");
+            }
+            setState(RESOLVED);
           }
 
         // Avoid writing class needlessly.
@@ -1971,15 +1892,26 @@ public class Compilation implements SourceLocator
                 dout.flush();
             }
             PushApply.pushApply(mexp, this);  
-            setState(messages.seenErrors() ? ERROR_SEEN : PRE_WALKED);
+            setState(PRE_WALKED);
           }
 
         if (wantedState >= WALKED && getState() < WALKED)
           {
             InlineCalls.inlineCalls(mexp, this);
+            if (enableANF)
+                ANormalize.aNormalize(mexp, this);
+            if (debugPrintANF) {
+                options.set("warn-void-used", Boolean.FALSE);
+                OutPort dout = OutPort.errDefault();
+                dout.println ("[Normalized module: "+mexp.getName()
+                             + " to " + mainClass.getName() + ":");
+                mexp.print(dout);
+                dout.println(']');
+                dout.flush();
+            }
             ChainLambdas.chainLambdas(mexp, this);
             FindTailCalls.findTailCalls(mexp, this);
-            setState(messages.seenErrors() ? ERROR_SEEN : WALKED);
+            setState(WALKED);
           }
 
         if (wantedState >= COMPILE_SETUP && getState() < COMPILE_SETUP)
@@ -1989,23 +1921,31 @@ public class Compilation implements SourceLocator
             FindCapturedVars.findCapturedVars(mexp, this);
             mexp.allocFields(this);
             mexp.allocChildMethods(this);
-            setState(messages.seenErrors() ? ERROR_SEEN : COMPILE_SETUP);
+            setState(COMPILE_SETUP);
           }
+        if (wantedState >= COMPILED && messages.seenErrors())
+            setState(ERROR_SEEN);
         if (wantedState >= COMPILED && getState() < COMPILED)
           {
-            if (immediate)
+            if (mexp.subModulesOnly())
               {
-                ClassLoader parentLoader = ObjectType.getContextClassLoader();
-                loader = new ArrayClassLoader(parentLoader);
+                setState(wantedState < CLASS_WRITTEN ? COMPILED : CLASS_WRITTEN);
+              }
+            else
+              {
+                if (immediate)
+                  {
+                    ClassLoader parentLoader = ObjectType.getContextClassLoader();
+                    loader = new ArrayClassLoader(parentLoader);
+                  }
+                generateBytecode();
+                setState(messages.seenErrors() ? ERROR_SEEN : COMPILED);
               }
-            generateBytecode();
-            setState(messages.seenErrors() ? ERROR_SEEN : COMPILED);
           }
-        if (wantedState >= CLASS_WRITTEN && getState() < CLASS_WRITTEN)
+        if (wantedState >= CLASS_WRITTEN && getState() < CLASS_WRITTEN
+            && ! mexp.subModulesOnly())
           {
-            if (! (mexp.getFlag(ModuleExp.HAS_SUB_MODULE)
-                   && mexp.body == QuoteExp.voidExp && mexp.firstDecl() == null))
-                outputClass(ModuleManager.getInstance().getCompilationDirectory());
+            outputClass(ModuleManager.getInstance().getCompilationDirectory());
             setState(CLASS_WRITTEN);
           }
       }
@@ -2061,7 +2001,15 @@ public class Compilation implements SourceLocator
     LambdaExp saveLambda = curLambda;
     curLambda = module;
     Type[] arg_types;
-    if (module.isHandlingTailCalls()) // Is this ever false?
+    String runName = "run";
+    int runFlags = Access.PUBLIC+Access.FINAL;
+    if (module.staticInitRun())
+      {
+	arg_types = Type.typeArray0;
+        runName = "$runBody$";
+        runFlags = Access.PRIVATE|Access.STATIC;
+      }
+    else if (module.isHandlingTailCalls()) // Is this ever false?
       {
 	arg_count = 1;
 	arg_types = new Type[1];
@@ -2085,9 +2033,8 @@ public class Compilation implements SourceLocator
     Variable heapFrame = module.heapFrame;
     boolean staticModule = module.isStatic();
     Method apply_method;
-    
-    apply_method = curClass.addMethod ("run", arg_types, Type.voidType,
-				       Access.PUBLIC+Access.FINAL);
+    apply_method = curClass.addMethod(runName, arg_types, Type.voidType,
+                                      runFlags);
     method = apply_method;
     // For each parameter, assign it to its proper slot.
     // If a parameter !isSimple(), we cannot assign it to a local slot,
@@ -2102,7 +2049,8 @@ public class Compilation implements SourceLocator
     module.heapFrame = module.isStatic() ? null : module.thisVariable;
     module.allocChildClasses(this);
 
-    if (module.isHandlingTailCalls() || usingCPStyle())
+    if (! module.staticInitRun()
+        && (module.isHandlingTailCalls() || usingCPStyle()))
       {
 	callContextVar = new Variable ("$ctx", typeCallContext);
 	module.getVarScope().addVariableAfter(thisDecl, callContextVar);
@@ -2169,10 +2117,8 @@ public class Compilation implements SourceLocator
             dumpInitializers(init);
           }
 
-	if (module.staticInitRun())
-	  {
-	    code.emitGetStatic(moduleInstanceMainField);
-	    code.emitInvoke(typeModuleBody.getDeclaredMethod("run", 0));
+	if (module.staticInitRun()) {
+	    code.emitInvoke(apply_method);
 	  }
 	code.emitReturn();
 
@@ -2209,7 +2155,6 @@ public class Compilation implements SourceLocator
 	    code.emitPushNull();
 	    code.emitStore(exceptionVar);
 	    // } catch (Throwable th) { exception = th; }
-	    code.emitTryEnd();
 	    code.emitCatchStart(exceptionVar);
 	    code.emitCatchEnd();
 	    code.emitTryCatchEnd();
@@ -2462,6 +2407,10 @@ public class Compilation implements SourceLocator
 
   public boolean isStatic() { return mainLambda.isStatic(); }
 
+    public boolean isInteractive() {
+        return mainLambda != null && mainLambda.getFlag(ModuleExp.INTERACTIVE);
+    }
+
   /** The same as getModule, until we allow nested modules. */
   public ModuleExp currentModule() { return current_scope.currentModule(); }
 
@@ -2529,11 +2478,7 @@ public class Compilation implements SourceLocator
   public ModuleExp pushNewModule (Lexer lexer)
   {
     this.lexer = lexer;
-    return pushNewModule(lexer.getName());
-  }
-
-  public ModuleExp pushNewModule (String filename)
-  {
+    String filename = lexer == null ? null : lexer.getName();
     ModuleExp module = new ModuleExp();
     if (filename != null)
       module.setFile(filename);
@@ -2543,7 +2488,8 @@ public class Compilation implements SourceLocator
     if (immediate)
       {
         module.setFlag(ModuleExp.IMMEDIATE);
-        new ModuleInfo().setCompilation(this);
+        ModuleInfo minfo = new ModuleInfo();
+        minfo.setCompilation(this);
       }
     push(module);
     return module;
@@ -2715,6 +2661,24 @@ public class Compilation implements SourceLocator
     messages.setLine(filename, line, column);
   }
 
+    /** Get source filename as an absolute Path, or null.
+     * Return null if there is no actual file, such as a {@code <string>}.
+     * Note the {@link ModuleInfo#getSourceAbsPath} is similar,
+     * but this version is not canonicalized.
+     */
+    public Path getSourceAbsPath() {
+        String currentFileName = getFileName();
+        if (currentFileName != null) {
+            ModuleInfo info = getMinfo();
+            // info.getSourceAbsPath() is null if the source port is
+            // a string or a console, in which we should return null.
+            if (info != null && info.getSourceAbsPath() != null) {
+                return Path.valueOf(currentFileName).getAbsolute();
+            }
+        }
+        return null;
+    }
+
   /** A help vector for building expressions. */
   public Stack<Expression> exprStack;
 
@@ -2860,6 +2824,12 @@ public class Compilation implements SourceLocator
         return let;
     }
 
+    /** A language-dependent "apply" function for generic application.
+     */
+    public Expression applyFunction(Expression func) {
+        return null;
+    }
+
   public QuoteExp makeQuoteExp (Object value)
   {
     return QuoteExp.getInstance(value, this);
