@@ -1,6 +1,7 @@
 package gnu.expr;
 
 import gnu.bytecode.*;
+import gnu.kawa.reflect.LazyType;
 import gnu.mapping.Values;
 
 /** This is the Target of a boolean expression, in a conditional context.
@@ -59,6 +60,7 @@ public class ConditionalTarget extends Target
                 zero = null;
             }
             if (zero != null && language.booleanValue(zero) > 0) {
+                code.emitPop(1);
                 code.emitGoto(ifTrue);
                 return;
             }
@@ -96,7 +98,8 @@ public class ConditionalTarget extends Target
 	return;
       case 'L':  case '[':
           if (language.booleanValue(null) == 0) {
-              if (Type.javalangBooleanType.compare(stackType) == -3)
+              if (Type.javalangBooleanType.compare(stackType) == -3
+                  && ! LazyType.maybeLazy(stackType))
                   comp.compileConstant(null);
               else {
                   code.emitInvokeStatic(isTrueMethod);
