@@ -398,7 +398,8 @@ public class Declaration
             comp.compileConstant(val, target);
             return;
           }
-        else if (value != QuoteExp.undefined_exp && ignorable()
+        else if (value != QuoteExp.undefined_exp && value != null
+                 && ignorable()
                  && ! (value instanceof LambdaExp))
           {
             value.compile(comp, target);
@@ -1005,7 +1006,7 @@ public class Declaration
       {
         String vname = null;
         if (symbol != null)
-          vname = Compilation.mangleNameIfNeeded(getName());
+          vname = Mangling.mangleNameIfNeeded(getName());
 	if (isAlias() && getValue() instanceof ReferenceExp)
 	  {
 	    Declaration base = followAliases(this);
@@ -1246,7 +1247,7 @@ public class Declaration
           }
         else
           {
-            fname = Compilation.mangleNameIfNeeded(fname);
+            fname = Mangling.mangleNameIfNeeded(fname);
             if (getFlag(IS_UNKNOWN))
               {
                 fname = UNKNOWN_PREFIX + fname;
@@ -1295,7 +1296,7 @@ public class Declaration
               }
             // FIXME should optimize if uri == module.getNamespaceUri()
             if (haveUri || havePrefix
-                || ! Compilation.demangleName(fname, true).equals(dname))
+                || ! Mangling.demangleName(fname, true).equals(dname))
               {
                 AnnotationEntry ae = new AnnotationEntry(ClassType.make("gnu.expr.SourceName"));
                 ae.addMember("name", dname, Type.javalangStringType);
@@ -1409,7 +1410,7 @@ public class Declaration
                 ClassType procType
                   = (ClassType) ClassType.make(name.substring(0, colon));
                 name = name.substring(colon+1);
-                String fname = Compilation.mangleNameIfNeeded(name);
+                String fname = Mangling.mangleNameIfNeeded(name);
                 procField = procType.getDeclaredField(fname);
               }
             catch (Exception ex)
@@ -1425,7 +1426,7 @@ public class Declaration
             if (procClass != null)
               {
                 ClassType procType = (ClassType) Type.make(procClass);
-                String fname = Compilation.mangleNameIfNeeded(name);
+                String fname = Mangling.mangleNameIfNeeded(name);
                 procField = procType.getDeclaredField(fname);
               }
           }
