@@ -2,7 +2,7 @@ package gnu.expr;
 import gnu.bytecode.CodeAttr;
 import gnu.bytecode.Type;
 import gnu.mapping.*;
-import gnu.text.Printable;
+import gnu.kawa.format.Printable;
 import gnu.text.SourceLocator;
 import gnu.lists.Consumer;
 import java.io.PrintWriter;
@@ -166,24 +166,6 @@ public abstract class Expression extends Procedure0
     compile (comp, CheckedTarget.getInstance(lhs));
   }
 
-  /** Compile all but the first sub-"statement".
-   * A kludge used for constructor methods, since if the first "statement"
-   * is a super-constructor we need to inject initializer expressions. */
-  public static void compileButFirst (Expression exp, Compilation comp)
-  {
-    if (exp instanceof BeginExp)
-      {
-        BeginExp bexp = (BeginExp) exp;
- 	int n = bexp.length;
-        if (n == 0)
-          return;
-        Expression[] exps = bexp.exps;
-        compileButFirst(exps[0], comp);
-	for (int i = 1; i < n; i++)
-	  exps[i].compileWithPosition(comp, Target.Ignore);       
-      }
-  }
-
   /** Make a deep copy of this expression, if possible.
    * @param mapper used to lookup parts (expressions, declarations)
    *   that have been translated in the parent.
