@@ -635,7 +635,7 @@ public class LambdaExp extends ScopeExp {
             : comp.mainClass;
         String name = getName();
         String fname
-            = name == null ? "lambda" : Compilation.mangleNameIfNeeded(name);
+            = name == null ? "lambda" : Mangling.mangleNameIfNeeded(name);
         int fflags = Access.FINAL;
         if (nameDecl != null && nameDecl.context instanceof ModuleExp) {
             boolean external_access = nameDecl.needsExternalAccess();
@@ -924,7 +924,7 @@ public class LambdaExp extends ScopeExp {
         if (isInitMethod == 'C')
             nameBuf.append("<clinit>");
         else if (getSymbol() != null)
-            nameBuf.append(Compilation.mangleName(name));
+            nameBuf.append(Mangling.mangleName(name));
         if (getFlag(SEQUENCE_RESULT))
             nameBuf.append("$C");
         boolean withContext
@@ -1095,13 +1095,15 @@ public class LambdaExp extends ScopeExp {
             // (such as "run" or "apply").
             int renameCount = 0;
             int len = nameBuf.length();
+            String suffix = nameBuf.substring(nameBaseLength, len);
             retry:
             for (;;) {
                 for (ClassType t = ctype;  t != null; t = t.getSuperclass()) {
                     if (t.getDeclaredMethod(name, atypes) != null) {
-                        nameBuf.setLength(len);
+                        nameBuf.setLength(nameBaseLength);
                         nameBuf.append('$');
                         nameBuf.append(++renameCount);
+                        nameBuf.append(suffix);
                         name = nameBuf.toString();
                         continue retry;
                     }
@@ -1222,8 +1224,7 @@ public class LambdaExp extends ScopeExp {
                 // Later, we copy it from its incoming register
                 // to its home location heapFrame.  Here we just create and
                 // assign a Variable for the incoming (register) value.
-                String vname
-                    = Compilation.mangleName(decl.getName()).intern();
+                String vname = Mangling.mangleName(decl.getName()).intern();
                 Type vtype = decl.getType().getImplementationType();
                 var = decl.var = getVarScope().addVariable(null, vtype, vname);
                 //getVarScope().addVariableAfter(var, decl);
@@ -1860,6 +1861,21 @@ public class LambdaExp extends ScopeExp {
             prevMode = mode;
         }
         out.endLogicalBlock(")");
+        if (properties != null) {
+            int plen = properties.length;
+            for (int j = 0; j < plen; j += 2) {
+                Object key = properties[j];
+                if (key == null)
+                    continue;
+                out.writeSpaceFill();
+                out.startLogicalBlock("", false, "");
+                out.print(key);
+                out.print(":");
+                out.writeSpaceFill();
+                out.print(properties[j+1]);
+                out.endLogicalBlock("");
+            }
+        }
         out.writeSpaceLinear();
         if (body == null)
             out.print("<null body>");
