@@ -83,6 +83,7 @@ public abstract class Language
     { "brl", ".brl", "gnu.kawa.brl.BRL" },
     { "emacs", "elisp", "emacs-lisp", ".el", "gnu.jemacs.lang.ELisp" },
     { "xquery", ".xquery", ".xq", ".xql", "gnu.xquery.lang.XQuery" },
+    { "kashell", ".ksl", "gnu.q2.lang.Q2" },
     { "q2", ".q2", "gnu.q2.lang.Q2" },
     { "xslt", "xsl", ".xsl", "gnu.kawa.xslt.XSLT" },
     { "commonlisp", "common-lisp", "clisp", "lisp",
@@ -304,7 +305,7 @@ public abstract class Language
     return Values.empty;
   }
 
-  /** True if functions are in a separate anme space from variable.
+  /** True if functions are in a separate name space from variable.
    * Is true for e.g. Common Lisp, Emacs Lisp;  false for Scheme. */
   public boolean hasSeparateFunctionNamespace()
   {
@@ -1103,7 +1104,7 @@ public abstract class Language
             // FIXME move this to demangleName
             if (externalAccess)
                 fname = fname.substring(Declaration.PRIVATE_PREFIX.length());
-            fdname = Compilation.demangleName(fname, true).intern();
+            fdname = Mangling.demangleName(fname, true).intern();
         }
         try {
             SourceName sourceName = fld.getAnnotation(SourceName.class);
