@@ -101,7 +101,8 @@ public class ProcInitializer extends Initializer
             code.emitLoad(comp.moduleInstanceVar);
         }
         code.emitPushInt(proc.getSelectorValue(comp));
-        comp.compileConstant(pname, Target.pushObject);
+        comp.compileConstant(proc.getProperty(PropertySet.nameKey, pname),
+                             Target.pushObject);
         // If there are keyword arguments, we treat that as "unlimited" maxArgs,
         // so that ModuleBody.matchX methods call matchN.  A kludge, I guess.
         code.emitPushInt(proc.min_args
