@@ -11,7 +11,7 @@ public abstract class ScopeExp extends Expression
   Declaration decls;
   Declaration last;
 
-  private Scope scope;
+  protected Scope scope;
 
   public Declaration firstDecl () { return decls; }
 
@@ -203,7 +203,7 @@ public abstract class ScopeExp extends Expression
   }
 
   /** Add a new Declaration, with a message if there is an existing one. */
-  public Declaration getDefine (Object name, char severity, Compilation parser)
+  public Declaration getDefine (Object name, Compilation parser)
   {
     Declaration decl = lookup(name);
     if (decl == null)
@@ -313,6 +313,11 @@ public abstract class ScopeExp extends Expression
     return visitor.visitScopeExp(this, d);
   }
 
+    /** True if a class is generated for this scope.  */
+    public final boolean isClassGenerated() {
+        return this instanceof ModuleExp || this instanceof ClassExp;
+    }
+
   public String toString() { return getClass().getName()+"#"+id; }
 
   static int counter;
