@@ -51,7 +51,7 @@ public class SlotGet extends Procedure2
     if (arg2 instanceof gnu.bytecode.Field)
       {
         fname = ((gnu.bytecode.Field) arg2).getName();
-        name = Compilation.demangleName(fname, true);
+        name = Mangling.demangleName(fname, true);
       }
     else if (arg2 instanceof gnu.bytecode.ClassType)
       {
@@ -60,23 +60,17 @@ public class SlotGet extends Procedure2
     else if (arg2 instanceof gnu.bytecode.Method)
       {
         String mname = ((gnu.bytecode.Method) arg2).getName();
-        name = Compilation.demangleName(mname, false);
+        name = Mangling.demangleName(mname, false);
         if (mname.startsWith("get"))
           getName = mname;
         else if (mname.startsWith("is"))
           isName = mname;
         fname = null;
       }
-    else if (arg2 instanceof SimpleSymbol
-             /* #ifdef use:java.lang.CharSequence */
-             || arg2 instanceof CharSequence
-             /* #else */
-             // || arg2 instanceof gnu.lists.CharSeq || arg2 instanceof String
-             /* #endif */
-             )
+    else if (arg2 instanceof SimpleSymbol || arg2 instanceof CharSequence)
       {
         name = arg2.toString();
-        fname = gnu.expr.Compilation.mangleNameIfNeeded(name);
+        fname = Mangling.mangleNameIfNeeded(name);
       }
     else
       throw new WrongType(this, 2, arg2, "string");
@@ -223,7 +217,7 @@ public class SlotGet extends Procedure2
   public static Member
   lookupMember (ObjectType clas, String name, ClassType caller)
   {
-    String mname = Compilation.mangleNameIfNeeded(name);
+    String mname = Mangling.mangleNameIfNeeded(name);
     Member member = clas.getField(mname, -1);
     if (member == null && clas instanceof ClassType)
       member = ((ClassType) clas).getDeclaredClass(mname);
