@@ -59,13 +59,28 @@ public class KawaAutoHandler
     mcontext.addFlags(ModuleContext.IN_HTTP_SERVER);
     if (hctx.getClass().getName().endsWith("KawaServlet$Context"))
       mcontext.addFlags(ModuleContext.IN_SERVLET);
-    ModuleInfo minfo = (ModuleInfo) mmap.get(path);
+    Object[] cached = (Object[]) mmap.get(path);
+    ModuleInfo minfo;
+    String scriptPath = "";
+    if (cached != null) {
+        minfo = (ModuleInfo) cached[0];
+        scriptPath = (String)  cached[1];
+    } else {
+        minfo = null;
+        scriptPath = path;
+    }
     long now = System.currentTimeMillis();
     ModuleManager mmanager = mcontext.getManager();
     // Avoid checking the disk too much
     if (minfo != null
-        && now - minfo.lastCheckedTime < mmanager.lastModifiedCacheTime)
+        && now - minfo.lastCheckedTime < mmanager.lastModifiedCacheTime) {
+        if (path.startsWith(scriptPath))
+            hctx.setScriptAndLocalPath(scriptPath,
+                                       path.substring(scriptPath.length()));
+        else
+            hctx.setScriptAndLocalPath("", path);
       return mcontext.findInstance(minfo);
+    }
 
     int plen = path.length();
     // Temporarily preset script-path to "" while doing getResourceURL.
@@ -83,21 +98,23 @@ public class KawaAutoHandler
         for (;;)
           {
             int sl = xpath.lastIndexOf('/');
-            if (sl < 0)
-              break;
-            xpath = xpath.substring(0, sl);
+            xpath = sl < 0 ? "." : xpath.substring(0, sl);
             upath = xpath + "/+default+";
             url = hctx.getResourceURL(upath);
             if (url != null)
               {
-                hctx.setScriptAndLocalPath(path.substring(0, sl+1), path.substring(sl+1));
+                scriptPath = path.substring(0, sl+1);
+                hctx.setScriptAndLocalPath(scriptPath, path.substring(sl+1));
                 absPath = Path.valueOf(url);
                 break;
               }
+            if (sl < 0)
+              break;
           }
       }
     else
       {
+        scriptPath = path;
         hctx.setScriptAndLocalPath(path, "");
       }
 
@@ -126,8 +143,6 @@ public class KawaAutoHandler
     if (minfo.checkCurrent(mmanager, now))
       return mcontext.findInstance(minfo);
 
-    mmap.put(path, minfo);
-
     InputStream resourceStream = absPath.openInputStream();
     if (! (resourceStream instanceof BufferedInputStream))
       // Not just a performance issue, since we need marks to be supported
@@ -163,25 +178,7 @@ public class KawaAutoHandler
                   }
                 return null;
               }
-
-            String contentType = absPath.probeContentType();
-            if (contentType != null)
-                hctx.setContentType(contentType);
-
-            // should set content length.
-            long len = absPath.getContentLength();
-            hctx.sendResponseHeaders(200, null, len);
-            OutputStream out = hctx.getResponseStream();
-            byte[] buffer = new byte[4*1024];
-            for (;;)
-              {
-                int n = resourceStream.read(buffer);
-                if (n < 0)
-                  break;
-                out.write(buffer, 0, n);
-              }
-            resourceStream.close();
-            out.close();
+            HttpRequestContext.handleStaticFile(hctx, absPath);
             return null;
           }
       }
@@ -236,6 +233,7 @@ public class KawaAutoHandler
       }
 
     minfo.setModuleClass(cl);
+    mmap.put(path, new Object[] {minfo, scriptPath});
 
     //if (saveClass)  FIXME
     //  comp.outputClass(context.getRealPath("WEB-INF/classes")+'/');
