@@ -22,7 +22,7 @@ public class PreProcess
     static final String JAVA4_FEATURES = "+JAVA2 +use:java.util.IdentityHashMap +use:java.lang.CharSequence +use:java.lang.Throwable.getCause +use:java.net.URI +use:java.util.regex +SAX2 +use:java.nio";
     static final String NO_JAVA4_FEATURES = "-JAVA5 -use:java.util.IdentityHashMap -use:java.lang.CharSequence -use:java.lang.Throwable.getCause -use:java.net.URI -use:java.util.regex -use:org.w3c.dom.Node -JAXP-1.3 -use:javax.xml.transform -JAVA5 -JAVA6 -JAVA6COMPAT5 -JAXP-QName -use:java.text.Normalizer -use:javax.lang.model -SAX2 -use:java.nio -Android";
     static final String JAVA5_FEATURES = "+JAVA5 "+JAVA4_FEATURES+" +use:org.w3c.dom.Node +use:javax.xml.transform +JAXP-1.3 -JAXP-QName";
-    static final String NO_JAVA6_FEATURES = "-JAVA6 -JAVA7 -JAVA8 -use:java.lang.invoke -use:java.text.Normalizer -use:javax.lang.model";
+    static final String NO_JAVA6_FEATURES = "-JAVA6 -JAVA7 -JAVA8 -JAVA9 -use:java.lang.invoke -use:java.text.Normalizer -use:javax.lang.model";
 
     static String[] version_features = {
         "java1", "-JAVA2 "+NO_JAVA4_FEATURES+" "+NO_JAVA6_FEATURES,
@@ -32,10 +32,11 @@ public class PreProcess
         "java4", "-JAVA5 "+JAVA4_FEATURES+" -use:org.w3c.dom.Node -JAXP-1.3 -use:javax.xml.transform -JAXP-QName -JAVA6COMPAT5 -Android "+NO_JAVA6_FEATURES,
         "java4x", "-JAVA5 "+JAVA4_FEATURES+" +use:org.w3c.dom.Node +JAXP-1.3 +use:javax.xml.transform -JAXP-QName -JAVA6COMPAT5 -Android "+NO_JAVA6_FEATURES,
         "java5", JAVA5_FEATURES+" -JAVA6COMPAT5 -Android "+NO_JAVA6_FEATURES,
-        "java6compat5", JAVA5_FEATURES+" -JAVA6 -JAVA7 -JAVA8 +JAVA6COMPAT5 +use:java.text.Normalizer -use:javax.lang.model -use:java.lang.invoke -Android",
-        "java6", JAVA5_FEATURES+" +JAVA6 -JAVA7 -JAVA8 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model -use:java.lang.invoke -Android",
-        "java7", JAVA5_FEATURES+" +JAVA6 +JAVA7 -JAVA8 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model +use:java.lang.invoke -Android",
-        "java8", JAVA5_FEATURES+" +JAVA6 +JAVA7 +JAVA8 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model +use:java.lang.invoke -Android",
+        "java6compat5", JAVA5_FEATURES+" -JAVA6 -JAVA7 -JAVA8 -JAVA9 +JAVA6COMPAT5 +use:java.text.Normalizer -use:javax.lang.model -use:java.lang.invoke -Android",
+        "java6", JAVA5_FEATURES+" +JAVA6 -JAVA7 -JAVA8 -JAVA9 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model -use:java.lang.invoke -Android",
+        "java7", JAVA5_FEATURES+" +JAVA6 +JAVA7 -JAVA8 -JAVA9 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model +use:java.lang.invoke -Android",
+        "java8", JAVA5_FEATURES+" +JAVA6 +JAVA7 +JAVA8 -JAVA9 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model +use:java.lang.invoke -Android",
+        "java9", JAVA5_FEATURES+" +JAVA6 +JAVA7 +JAVA8 +JAVA9 -JAVA6COMPAT5 +use:java.text.Normalizer +use:javax.lang.model +use:java.lang.invoke -Android",
         "android", "+JAVA5 "+JAVA4_FEATURES+" +use:org.w3c.dom.Node +JAXP-1.3 -JAXP-QName -use:javax.xml.transform -JAVA6 -JAVA6COMPAT5 +Android "+NO_JAVA6_FEATURES,
 
         "OBJECT",
@@ -49,7 +50,7 @@ public class PreProcess
         +"/$TAG$=Bit/$tag$=b/$ptype$=boolean/$BTYPE$=Boolean"
         +"/$CNAME$=BitVector/$SUPER$=SimpleVector<Boolean>/$KIND$=BOOLEAN"
         +"/$RETURN_IF_UNEQUAL$(v1,v2)=return v1 && ! v2 ? 1 : -1"
-        +"/$WRITE(i,out)=out.writeBoolean(booleanAt(i))/$ZERO$=false",
+        +"/$WRITE(i,out)=out.writeBoolean(getBoolean(i))/$ZERO$=false",
         "BYTE",
         "/+BYTE/$DESC$=signed or unsigned 8-bit integers (bytes)"
         +"/$TAG$=Byte/$ptype$=byte/$BTYPE$=E"
@@ -70,12 +71,12 @@ public class PreProcess
         "/+F32/$DESC$=32-bit floats"
         +"/$TAG$=F32/$ptype$=float/$BTYPE$=Float"
         +"/$CNAME$=F32Vector/$SUPER$=SimpleVector<Float>/$KIND$=FLOAT"
-        +"/$WRITE(i,out)=out.writeFloat(floatAt(i))",
+        +"/$WRITE(i,out)=out.writeFloat(getFloat(i))",
         "F64",
         "/+F64/$DESC$=64-bit doubles"
         +"/$TAG$=F64/$ptype$=double/$BTYPE$=Double"
         +"/$CNAME$=F64Vector/$SUPER$=SimpleVector<Double>/$KIND$=DOUBLE"
-        +"/$WRITE(i,out)=out.writeDouble(doubleAt(i))",
+        +"/$WRITE(i,out)=out.writeDouble(getDouble(i))",
         "S8",
         "/+S8/$DESC$=signed 8-bit integers (bytes)"
         +"/$TAG$=S8/$ptype$=byte/$BTYPE$=Byte/$KIND$=INT_S8"
@@ -92,7 +93,7 @@ public class PreProcess
         "/+S64/$DESC$=signed 64-bit integers (longs)"
         +"/$TAG$=S64/$ptype$=long/$BTYPE$=Long/$KIND$=INT_S64"
         +"/$CNAME$=S64Vector/$SUPER$=LongVector<Long>"
-        +"/$WRITE(i,out)=out.writeLong(longAt(i))",
+        +"/$WRITE(i,out)=out.writeLong(getLong(i))",
         "U8",
         "/+U8/$DESC$=unsigned 8-bit integers (bytes)"
         +"/$TAG$=U8/$ptype$=byte/$BTYPE$=UByte/$KIND$=INT_U8"
@@ -105,12 +106,12 @@ public class PreProcess
         "/+U32/$DESC$=unsigned 32-bit integers (ints)"
         +"/$TAG$=U32/$ptype$=int/$BTYPE$=UInt/$KIND$=INT_U32"
         +"/$CNAME$=U32Vector/$SUPER$=IntVector<UInt>/$MASK$= & 0xffffffffL"
-        +"/$WRITE(i,out)=Sequences.writeUInt(intAt(i), out)",
+        +"/$WRITE(i,out)=Sequences.writeUInt(getInt(i), out)",
         "U64",
         "/+U64/$DESC$=unsigned 64-bit integers (longs)"
         +"/$TAG$=U64/$ptype$=long/$BTYPE$=ULong/$KIND$=INT_U64"
         +"/$CNAME$=U64Vector/$SUPER$=LongVector<ULong>"
-        +"/$WRITE(i,out)=Sequences.writeULong(longAt(i), out)"
+        +"/$WRITE(i,out)=Sequences.writeULong(getLong(i), out)"
         +"/$RETURN_IF_UNEQUAL(v1,v2)=return (v1^0x8000000000000000L) > (v2^0x8000000000000000L) ? 1 : -1",
     };
 
