@@ -373,8 +373,13 @@ public class IntNum extends RatNum implements Externalizable
   /** Add two IntNums, yielding their sum as another IntNum. */
   public static IntNum add (IntNum x, IntNum y, int k)
   {
-    if (x.words == null && y.words == null)
-      return IntNum.make ((long) k * (long) y.ival + (long) x.ival);
+    if (y.words == null) {
+        int yval = y.ival;
+        if (yval == 0)
+            return x;
+        if (x.words == null)
+            return IntNum.make((long) k * (long) yval + (long) x.ival);
+    }
     if (k != 1)
       {
 	if (k == -1)
@@ -1281,6 +1286,10 @@ public class IntNum extends RatNum implements Externalizable
     return num;
   }
 
+    public static IntNum make(int[] words) {
+        return make(words, words.length);
+    }
+
     public static IntNum make(long value) {
         return valueOf(value);
     }
@@ -1626,7 +1635,7 @@ public class IntNum extends RatNum implements Externalizable
   }
 
   /**
-   * @serialData If the value is in the range (int)0xC000000 .. 0x7fffffff
+   * @serialData If the value is in the range (int)0xC0000000 .. 0x7fffffff
    * (inclusive) write out the value (using writeInt).
    * Otherwise, write (using writeInt) (0x80000000|nwords), where nwords is
    * the number of words following.  The words are the minimal
