@@ -1218,7 +1218,7 @@ public class Translator extends Compilation
             else {
                 if (cname.indexOf('.') < 0)
                     cname = (tr.classPrefix
-                             + Compilation.mangleNameIfNeeded(cname));
+                             + Mangling.mangleNameIfNeeded(cname));
                 if (rank == 0) {
                     ModuleManager mmanager = ModuleManager.getInstance();
                     ModuleInfo typeInfo = mmanager.searchWithClassName(cname);
@@ -1869,7 +1869,7 @@ public class Translator extends Compilation
 
   public void resolveModule(ModuleExp mexp)
   {
-    setLine(null, -1, -1);
+    Expression savePos = new ReferenceExp((Object) null);
     int numPending = pendingImports == null ? 0 : pendingImports.size();
     for (int i = 0;  i < numPending;  )
       {
@@ -1880,7 +1880,6 @@ public class Translator extends Compilation
         if (mexp == defs)
           {
             // process(BODY_PARSED);
-            Expression savePos = new ReferenceExp((Object) null);
             savePos.setLine(this);
             setLine(posExp);
             Pair beforeImports = formStack.last;
@@ -1902,8 +1901,10 @@ public class Translator extends Compilation
           }
       }
     pendingImports = null;
-
     setModule(mexp);
+
+    savePos.setLine(this);
+    setLine(null, -1, -1);
     Compilation save_comp = Compilation.setSaveCurrent(this);
     try
       {
@@ -1929,6 +1930,7 @@ public class Translator extends Compilation
     finally
       {
 	Compilation.restoreCurrent(save_comp);
+        setLine(savePos);
       }
 
     /* DEBUGGING:
@@ -1964,7 +1966,7 @@ public class Translator extends Compilation
   }
 
   /** Push an alias for a declaration in a scope.
-   * If the name of {@code decl}> came from a syntax template
+   * If the name of {@code decl} came from a syntax template
    * whose immediate scope is {@code templateScope},
    * then the same syntax template may contain local variable references
    * that are also in the same {@code templateScope}.
