@@ -2,13 +2,11 @@
 (require <kawa.lib.std_syntax>)
 (require <kawa.lib.syntax>)
 (require <kawa.lib.misc>)
-(define-alias Double java.lang.Double)
-(define-alias IntNum gnu.math.IntNum)
-(define-alias Numeric gnu.math.Numeric)
-(define-alias RatNum gnu.math.RatNum)
-(define-alias RealNum gnu.math.RealNum)
-(define-alias LangObjType gnu.kawa.lispexpr.LangObjType)
-(define-alias quaternion gnu.math.Quaternion)
+
+(import (class java.lang Double)
+        (class gnu.math
+               IntNum BitOps Numeric RatNum RealNum (Quaternion quaternion))
+        (class gnu.kawa.lispexpr LangObjType))
 
 (define-private (java.lang.real? x) ::boolean
   (and (java.lang.Number? x)
@@ -336,6 +334,76 @@
                   (v (if (= 0 u) +i u)))
              (* 1/2 v (log (* (+ v q) (/ (- v q))))))))))
 
+(define-procedure sinh
+  (lambda (z ::complex)
+    ::complex
+    (let ((x ::double (real-part z))
+          (y ::double (imag-part z)))
+      (complex:make (* (java.lang.Math:sinh x) (java.lang.Math:cos y))
+                    (* (java.lang.Math:cosh x) (java.lang.Math:sin y)))))
+  (lambda (q ::quaternion)
+    ::quaternion
+    (/ (- (exp q) (exp (- q))) 2))
+  (lambda (x ::double)
+    ::double
+    (java.lang.Math:sinh x)))
+
+(define-procedure cosh
+  (lambda (z ::complex)
+    ::complex
+    (let ((x ::double (real-part z))
+          (y ::double (imag-part z)))
+      (complex:make (* (java.lang.Math:cosh x) (java.lang.Math:cos y))
+                    (* (java.lang.Math:sinh x) (java.lang.Math:sin y)))))
+  (lambda (q ::quaternion)
+    ::quaternion
+    (/ (+ (exp q) (exp (- q))) 2))
+  (lambda (x ::double)
+    ::double
+    (java.lang.Math:cosh x)))
+
+(define-procedure tanh
+  (lambda (z ::complex)
+    ::complex
+    (let ((x ::double (* 2 (real-part z)))
+          (y ::double (* 2 (imag-part z))))
+      (let ((w ::double (+ (java.lang.Math:cosh x)
+                           (java.lang.Math:cos y))))
+        (complex:make (/ (java.lang.Math:sinh x) w)
+                      (/ (java.lang.Math:sin y) w)))))
+  (lambda (q ::quaternion)
+    ::quaternion
+    (let ((e^q ::quaternion (exp q))
+          (e^-q ::quaternion (exp (- q))))
+      (/ (- e^q e^-q) (+ e^q e^-q))))
+  (lambda (x ::double)
+    ::double
+    (java.lang.Math:tanh x)))
+
+(define-procedure asinh
+  (lambda (q ::quaternion)
+    ::quaternion
+    (log (+ q (sqrt (+ (* q q) 1)))))
+  (lambda (x ::double)
+    ::double
+    (java.lang.Math:log (+ x (java.lang.Math:sqrt (+ (* x x) 1))))))
+
+(define-procedure acosh
+  (lambda (q ::quaternion)
+    ::quaternion
+    (log (+ q (* (sqrt (+ q 1)) (sqrt (- q 1))))))
+  (lambda (x ::double)
+    ::double
+    (java.lang.Math:log (+ x (java.lang.Math:sqrt (- (* x x) 1))))))
+
+(define-procedure atanh
+  (lambda (q ::quaternion)
+    ::quaternion
+    (/ (- (log (+ 1 q)) (log (- 1 q))) 2))
+  (lambda (x ::double)
+    ::double
+    (* 0.5 (java.lang.Math:log (/ (+ 1 x) (- 1 x))))))
+
 (define (sqrt x::java.lang.Number) ::java.lang.Number
   (cond ((java.lang.real? x)
          (java.lang.Math:sqrt x))
@@ -344,7 +412,7 @@
            (gnu.math.Quantity:make ((num:number):sqrt)
                                    ((num:unit):sqrt))))))
 
-(define (square x::quantity) ::quantity
+(define (square x::java.lang.Number) ::java.lang.Number
   (* x x))
 
 (define-procedure make-rectangular
@@ -390,7 +458,7 @@
 (define (angle (x ::java.lang.Number)):: <real>
   (if (gnu.math.Quaternion? x)
       ((->gnu.math.Quaternion x):angle)
-      (if (< (x:doubleValue) 0) java.lang.Math:PI 0)))
+      (if (< (x:doubleValue) 0) java.lang.Math:PI 0.0)))
 
 (define (inexact (num :: java.lang.Number)) :: java.lang.Number
   (gnu.kawa.functions.Arithmetic:toInexact num))
@@ -405,48 +473,45 @@
   (gnu.kawa.functions.Arithmetic:toExact num))
 
 (define (logop (op :: <int>) (i :: <integer>) (j :: <integer>)) :: <integer>
-  (invoke-static <gnu.math.BitOps> 'bitOp op i j))
+  (BitOps:bitOp op i j))
 
 (define (bitwise-bit-set? (i :: <integer>) (bitno :: <int>)) :: <boolean>
-  (gnu.math.BitOps:bitValue i bitno))
+  (BitOps:bitValue i bitno))
 
 (define (bitwise-copy-bit (i :: integer) (bitno :: int) (new-value :: int))
   :: integer
-  (gnu.math.BitOps:setBitValue i bitno new-value))
+  (BitOps:setBitValue i bitno new-value))
 
 (define (bitwise-copy-bit-field (to :: integer) (start :: int) (end :: int) (from :: integer)) ::  integer
-  (let* ((mask1 (gnu.math.IntNum:shift -1 start))
-	 (mask2 (gnu.math.BitOps:not (gnu.math.IntNum:shift -1 end)))
-	 (mask (gnu.math.BitOps:and mask1 mask2)))
-    (bitwise-if mask
-		(gnu.math.IntNum:shift from start)
-		to)))
+  (bitwise-if (BitOps:makeMask start end)
+              (IntNum:shift from start)
+              to))
 
 (define (bitwise-bit-field (i :: <integer>) (start :: <int>) (end :: <int>))
   :: <integer>
-  (invoke-static <gnu.math.BitOps> 'extract i start end))
+  (BitOps:extract i start end))
 
-(define (bitwise-if (e1 :: integer) (e2 :: integer) (e3  integer)) :: integer
-  (gnu.math.BitOps:ior (gnu.math.BitOps:and e1 e2)
-		       (gnu.math.BitOps:and (gnu.math.BitOps:not e1) e3)))
+(define (bitwise-if (e1 :: integer) (e2 :: integer) (e3 :: integer)) :: integer
+  (BitOps:ior (BitOps:and e1 e2)
+		       (BitOps:and (BitOps:not e1) e3)))
 
 (define (logtest (i :: <integer>) (j :: <integer>))
-  (invoke-static <gnu.math.BitOps> 'test i j))
+  (BitOps:test i j))
 
 (define (logcount (i :: <integer>)) :: <int>
-  (gnu.math.BitOps:bitCount
-   (if (>= i 0) i (gnu.math.BitOps:not i))))
+  (BitOps:bitCount
+   (if (>= i 0) i (BitOps:not i))))
 
 (define (bitwise-bit-count (i :: <integer>)) :: <int>
   (if (>= i 0)
-      (gnu.math.BitOps:bitCount i)
-      (- -1 (gnu.math.BitOps:bitCount (gnu.math.BitOps:not i)))))  
+      (BitOps:bitCount i)
+      (- -1 (BitOps:bitCount (BitOps:not i)))))  
 
 (define (bitwise-length (i :: <integer>)) :: <int>
   (invoke i 'intLength))
 
 (define (bitwise-first-bit-set (i :: <integer>)) :: <int>
-  (gnu.math.BitOps:lowestBitSet i))
+  (BitOps:lowestBitSet i))
 
 (define (bitwise-rotate-bit-field (n :: integer) (start :: int) (end :: int) (count :: int)) :: integer
   (let ((width (- end start)))
@@ -457,12 +522,12 @@
 	       (field0 (bitwise-bit-field n start end))
 	       (field1 (gnu.math.IntNum:shift field0 count))
 	       (field2 (gnu.math.IntNum:shift field0 (- count width)))
-	       (field (gnu.math.BitOps:ior field1 field2)))
+	       (field (BitOps:ior field1 field2)))
 	  (bitwise-copy-bit-field n start end field))
 	n)))
 
 (define (bitwise-reverse-bit-field (n :: integer) (start :: int) (end :: int)) :: integer
-  (gnu.math.BitOps:reverseBits n start end))
+  (BitOps:reverseBits n start end))
 
 (define (number->string (arg :: <java.lang.Number>)
 			#!optional (radix :: <int> 10)) ::string
@@ -508,8 +573,9 @@
                         (format #f "negative argument: ~A" i))))
   (let* ((dval ::double (i:doubleValue))
          (init ::integer ;; initial approximation
-               (if (Double:isInfinite dval) 
-                   (IntNum:shift 1 (i:intLength))
+               (if (Double:isInfinite dval)
+                   (let ((il (i:intLength)))
+                     (BitOps:makeMask il (+ il 1)))
                    (RealNum:toExactInt (java.lang.Math:sqrt dval)
                                        Numeric:TRUNCATE))))
     ;; "Babylonian method"
