@@ -9,12 +9,15 @@
 	       syntax-source syntax-line syntax-column)
 
 (require <kawa.lib.prim_syntax>)
+(import (only kawa.standard.syntax syntax))
+(import (only kawa.standard.syntax_case (syntax_case syntax-case)))
 
 (import (rename (only (kawa standard let) let) (let %let)))
 (import (rename (only (kawa standard define) defineRaw) (defineRaw %define)))
 (import (only (kawa standard SchemeCompilation) lambda))
 (import (only (kawa standard Scheme) not))
 (import (only (kawa standard begin) begin))
+(import (only kawa.standard.syntax_error (syntax_error syntax-error)))
 
 (define-syntax ?
   (syntax-rules ()
