@@ -101,7 +101,7 @@ public class ImportFromLibrary extends Syntax
 
     public static String checkSrfi(String lname, Translator tr) {
         if (lname.startsWith("srfi.")) {
-            String demangled = Compilation.demangleSymbolic(lname.substring(5));
+            String demangled = Mangling.demangleSymbolic(lname.substring(5));
             int dot = demangled.indexOf('.');
             String srfiName;
             StringBuilder badNameBuffer = null;
@@ -162,7 +162,7 @@ public class ImportFromLibrary extends Syntax
         if (imports instanceof SimpleSymbol) {
             String sname = imports.toString();
             handleImport(sname, null,
-                         Compilation.mangleQualifiedName(sname),
+                         Mangling.mangleQualifiedName(sname),
                          defs, tr, mapper);
             return;
         }
@@ -283,7 +283,7 @@ public class ImportFromLibrary extends Syntax
                 if (sbuf.length() > 0)
                     sbuf.append('/');
                 String part = car.toString();
-                cbuf.append(Compilation.mangleClassName(part));
+                cbuf.append(Mangling.mangleClassName(part));
                 sbuf.append(part);
             }
             libref = cdr;
@@ -509,6 +509,7 @@ public class ImportFromLibrary extends Syntax
                     Pair pair = (Pair) lst;
                     Object save1 = tr.pushPositionOf(pair);
                     Object name = Translator.stripSyntax(pair.getCar());
+                    name = tr.namespaceResolve(name);
                     Symbol oldsym = null;
                     Symbol newsym = null;
                     if (name instanceof Symbol) {
@@ -519,6 +520,8 @@ public class ImportFromLibrary extends Syntax
                         Pair rpair1 = (Pair) name;
                         Object rname1 = rpair1.getCar();
                         Object rname2 = ((Pair) rpair1.getCdr()).getCar();
+                        rname1 = tr.namespaceResolve(rname1);
+                        rname2 = tr.namespaceResolve(rname2);
                         if (rname1 instanceof Symbol
                             && rname2 instanceof Symbol) {
                             oldsym = (Symbol) rname1;
