@@ -24,7 +24,10 @@ public class SchemeCompilation extends Translator
 
     @Override
     public Expression applyFunction(Expression func) {
-        return new ReferenceExp(applyFieldDecl);
+        if (func instanceof LambdaExp)
+            return null;
+        else
+            return new ReferenceExp(applyFieldDecl);
     }
 
   @Override
@@ -52,6 +55,10 @@ public class SchemeCompilation extends Translator
   public static final kawa.repl repl;
 
   public static final Lambda lambda = new kawa.lang.Lambda();
+  public static final Lambda mlambda = new kawa.lang.Lambda();
+  static { mlambda.handlePatterns = true;
+    mlambda.setKeywords(Special.optional, Special.rest, Special.key);
+  }
 
   static
   {
@@ -76,6 +83,8 @@ public class SchemeCompilation extends Translator
             return null;
         int llen = local.length();
         // Map 'TYPE?' to '(lambda (obj) (instance? obj TYPE))'.
+        // FIXME - this should be done after/during InlineCalls,
+        // so we only do this if TYPE is a Type or Class.
         if (len > 1 && llen > 1 && name.charAt(len-1) == '?') {
             String tlocal = local.substring(0, llen-1).intern();
             Symbol tsymbol = namespace.getSymbol(tlocal);
@@ -91,6 +100,7 @@ public class SchemeCompilation extends Translator
                 LambdaExp lexp = new LambdaExp(1);
                 lexp.setSymbol(symbol);
                 Declaration param = lexp.addDeclaration((Object) null);
+                param.setFlag(Declaration.IS_PARAMETER);
                 param.noteValueUnknown();
                 lexp.body = new ApplyExp(Scheme.instanceOf,
                                          new ReferenceExp(param), texp);
@@ -98,6 +108,8 @@ public class SchemeCompilation extends Translator
             }
         }
         // Map '->TYPE' to '(lambda (obj) (as TYPE obj))'.
+        // FIXME - this should be done after/during InlineCalls,
+        // so we only do this if TYPE is a Type or Class.
         if (len > 2 && llen > 2
             && name.charAt(0) == '-' && name.charAt(1) == '>') {
             String tlocal = local.substring(2).intern();
