@@ -21,25 +21,21 @@ public class make extends ProcedureN
     else
       clas = null;
     if (clas == null)
-      throw new WrongType("make", 1, "class");
+      throw new WrongType(this, 1, arg_0, "class");
     Object result;
     try
       {
 	result = clas.newInstance();
       }
-    catch (InstantiationException ex)
+    catch (Exception ex)
       {
-	throw new GenericError (ex.toString());
-      }
-    catch (IllegalAccessException ex)
-      {
-	throw new GenericError (ex.toString());
+	throw new WrappedException(ex);
       }
     for (int i = 1;  i < nargs;  )
       {
 	Keyword key = (Keyword) args[i++];
 	Object arg = args[i++];
-	Record.set1(result, arg, key.getName());
+	Record.set1(arg, key.getName(), result);
       }
     return result;
   }
