@@ -170,7 +170,7 @@ public class require extends Syntax
                 && requestedClass.charAt(nlen-1) == '>')
                 requestedClass = requestedClass.substring(1, nlen-1);
             String implicitSource = requestedClass.replace('.', '/');
-            requestedClass = Compilation.mangleQualifiedName(requestedClass);
+            requestedClass = Mangling.mangleQualifiedName(requestedClass);
             String explicitSource = null;
             if (args.getCdr() instanceof Pair) {
                 Object sname = ((Pair) args.getCdr()).getCar();
@@ -236,7 +236,7 @@ public class require extends Syntax
                 if (tr.immediate)
                     options |= Language.PARSE_IMMEDIATE;
                 comp = language.parse(fstream, messages, options, info);
-                if (tr.getModule().getFlag(ModuleExp.INTERACTIVE));
+                if (tr.getModule().getFlag(ModuleExp.INTERACTIVE))
                     comp.getModule().setFlag(ModuleExp.INTERACTIVE);
             } catch (java.io.FileNotFoundException ex) {
                 tr.error('e', "not found: "+ex.getMessage());
@@ -311,7 +311,7 @@ public class require extends Syntax
         Map<Symbol,Expression> dmap
             = new LinkedHashMap<Symbol,Expression>();
         Map<String,Declaration> moduleReferences = null;
-       
+
         for (Declaration fdecl = mod.firstDecl();
              fdecl != null;  fdecl = fdecl.nextDecl()) {
             if (fdecl.isPrivate())
