@@ -1,4 +1,25 @@
-(test-begin "num" 1881)
+(test-begin "num" 1909)
+
+(define-syntax jequals
+  (syntax-rules ()
+    ((jequals x y)
+     (invoke x 'equals y))))
+(define-syntax test-jequals
+  (syntax-rules ()
+    ((test-jequals x y)
+     (test-assert (jequals x y)))))
+
+(test-assert (not (jequals (java.lang.Integer:valueOf 45)
+                           (gnu.math.UInt:valueOf 45))))
+(test-assert (not (jequals (java.lang.Integer:valueOf 45)
+                           (gnu.math.IntNum:valueOf 45))))
+#|
+Not currently true, but perhaps it should be.
+(test-assert (not (eqv? (java.lang.Integer:valueOf 45)
+                        (gnu.math.UInt:valueOf 45))))
+(test-assert (not (eqv? (java.lang.Integer:valueOf 45)
+                        (gnu.math.IntNum:valueOf 45))))
+|#
 
 (test-equal 7 (+ 3 4))
 (test-equal 3 (+ 3))
@@ -177,7 +198,6 @@
 (test-equal #i1/3 (rationalize .3 1/10)) ; approximately
 (test-equal +inf.0 (rationalize +inf.0 3))
 (test-equal +nan.0 (rationalize +inf.0 +inf.0))
-(test-expect-fail 1)
 (test-equal 0.0 (rationalize 3 +inf.0))
 
 (test-end "convert")
@@ -466,4 +486,43 @@
 
 (test-assert (not (gnu.math.Complex:equals 3+4i 3+5i)))
 
+(require <InliningTest>)
+
+(for-each (lambda (vals)
+            (let (([x y r] vals))
+              (test-equal r (greater-equal-u32-s32 x y))
+              (test-equal r (greater-equal-u32-s32-generic x y))))
+          '((#xffffffff 3 #t)
+            (#xfffffffc #x7fffffff #t)
+            (#xfffffffc #xffffffff #t)
+            (#x7ffffffc #x7fffffff #f)
+            (#xffffffff -3 #t)))
+
+(for-each (lambda (vals)
+            (let (([x y r] vals))
+              (test-equal r (greater-equal-u64-u64 x y))
+              (test-equal r (greater-equal-u64-u64-generic x y))))
+          '((#xffffffffffffffff 3 #t)
+            (#xfffffffffffffffA #xfffffffffffffffC #f)))
+
+(test-equal 65586 (add-u8a-u16a))
+
+;; To avoid inlining, use a wrapper function.
+(define (my-ashift x y::int) (arithmetic-shift x y))
+(test-jequals (->uint #xf80000A8) (my-ashift (->uint #xFF000015) 3))
+(test-jequals (->uint #x1fe00002) (my-ashift (->uint #xFF000015) -3))
+(test-jequals (->int -134217560) (my-ashift (->int (->uint #xFF000015)) 3))
+(test-jequals (->int -2097150) (my-ashift (->int (->uint #xFF000015)) -3))
+
+(test-equal (->int 253) (->int (index-u8v1 1)))
+(test-equal (->int 253) (->int (index-u8i1 1)))
+(test-equal (->int 253) (->int (index-u8i2 1)))
+
+(define u32x ::uint #xFFFFFFF0)
+(test-assert (= u32x #xFFFFFFF0))
+(test-assert (= u32x (+ (->uint #xFFFFFFE8) 8)))
+(let* ((vec1 ::dynamic (u32vector 4 5 6 7)))
+  (set! (vec1 2) u32x)
+  (test-equal u32x (vec1 2))
+  (test-equal 7 (vec1 3)))
 (test-end)
