@@ -174,10 +174,103 @@
   (set! (str1 [2 <: 2]) (str1 [1 <: 4]))
   (test-equal "abbDdDdef" str1)
   (! str2 (str1 [8 2 4 0 5]))
-  (test-equal "fbdaD" str2)
+  (! str3 (array-index-share str1 [8 2 4 0 5]))
   (test-equal "gnu.lists.FString" (invoke (invoke str1 'getClass) 'getName))
-  (test-equal "gnu.lists.FString" (invoke (invoke str2 'getClass) 'getName))
-  (set! (str2 4) #\x)
+  (test-error (set! (str2 4) #\x))
+  (set! (str3 4) #\x)
+  (test-equal "fbdaD" str2)
   (test-equal "abbDdxdef" str1))
 
+(test-begin "pretty-printing")
+
+(import (kawa pprint))
+
+(define (format-pretty form width)
+  (fluid-let ((*print-right-margin* width))
+    (! swr (java.io.StringWriter))
+    (! out (gnu.kawa.io.OutPort swr #t #f))
+    (out:setPrettyPrinting #t)
+    (pprint form out)
+    (out:close)
+    (swr:toString)))
+
+(define-syntax test-pretty-print
+  (syntax-rules ()
+    ((_ form width expected)
+     (test-equal expected (format-pretty form width)))))
+
+(define form-1
+  '(define-private (foo fdsf add) (list b 23) (let ((xy (+ dadasd asdasd)) (xz 12)) (list b 22) ABCD (vector 42343 23423423 234324 989))))
+
+(test-pretty-print form-1 30 &{
+    &|(define-private (foo fdsf
+    &|                 add)
+    &|  (list b 23)
+    &|  (let ((xy
+    &|         (+ dadasd asdasd))
+    &|        (xz 12))
+    &|    (list b 22)
+    &|    ABCD
+    &|    (vector 42343 23423423
+    &|     234324 989)))})
+
+(test-pretty-print form-1 50 &{
+    &|(define-private (foo fdsf add)
+    &|  (list b 23)
+    &|  (let ((xy (+ dadasd asdasd)) (xz 12))
+    &|    (list b 22)
+    &|    ABCD
+    &|    (vector 42343 23423423 234324 989)))})
+
+(define form-2
+  '(if (equal? fdfds sdfsdf) (cond (aa (list bb)) ((null? cc) dd)) (vector xx sxasxs (+ 454 435) dsadd)))
+
+(test-pretty-print form-2 20 &{
+    &|(if (equal? fdfds
+    &|     sdfsdf)
+    &|    (cond (aa
+    &|           (list
+    &|            bb))
+    &|          ((null?
+    &|            cc)
+    &|           dd))
+    &|    (vector xx
+    &|     sxasxs
+    &|     (+ 454 435)
+    &|     dsadd))})
+
+(test-pretty-print form-2 40 &{
+    &|(if (equal? fdfds sdfsdf)
+    &|    (cond (aa (list bb))
+    &|          ((null? cc) dd))
+    &|    (vector xx sxasxs (+ 454 435)
+    &|     dsadd))})
+
+(test-pretty-print form-2 80 &{
+    &|(if (equal? fdfds sdfsdf)
+    &|    (cond (aa (list bb)) ((null? cc) dd))
+    &|    (vector xx sxasxs (+ 454 435) dsadd))})
+
+(test-pretty-print form-2 200 &{
+    &|(if (equal? fdfds sdfsdf) (cond (aa (list bb)) ((null? cc) dd)) (vector xx sxasxs (+ 454 435) dsadd))})
+
+(define form-3
+  '(if (equal? xyz (list asdsads bccc)) (list xyz xyz) (list 987 xy)))
+
+(test-pretty-print form-3 200 &{
+    &|(if (equal? xyz (list asdsads bccc)) (list xyz xyz) (list 987 xy))})
+
+(test-pretty-print form-3 40 &{
+    &|(if (equal? xyz (list asdsads bccc))
+    &|    (list xyz xyz)
+    &|    (list 987 xy))})
+
+(test-pretty-print form-3 30 &{
+    &|(if (equal? xyz
+    &|     (list asdsads bccc))
+    &|    (list xyz xyz)
+    &|    (list 987 xy))})
+
+(test-end)
+  
 (test-end)
